@@ -6,6 +6,8 @@ var annotated_dup =
     [ "application", "namespaceapplication.html", [
       [ "application_shell", "classapplication_1_1application__shell.html", "classapplication_1_1application__shell" ],
       [ "base_application", "classapplication_1_1base__application.html", "classapplication_1_1base__application" ],
+      [ "callstack_tracker", "classapplication_1_1callstack__tracker.html", "classapplication_1_1callstack__tracker" ],
+      [ "frame_tracking_instance", "classapplication_1_1frame__tracking__instance.html", "classapplication_1_1frame__tracking__instance" ],
       [ "command_parameter", "classapplication_1_1command__parameter.html", "classapplication_1_1command__parameter" ],
       [ "command_line", "classapplication_1_1command__line.html", "classapplication_1_1command__line" ],
       [ "hoople_service", "classapplication_1_1hoople__service.html", "classapplication_1_1hoople__service" ],
@@ -120,7 +122,7 @@ var annotated_dup =
       [ "int_averager", "classmathematics_1_1int__averager.html", "classmathematics_1_1int__averager" ],
       [ "chaos", "classmathematics_1_1chaos.html", "classmathematics_1_1chaos" ],
       [ "double_plus", "classmathematics_1_1double__plus.html", "classmathematics_1_1double__plus" ],
-      [ "math_ops", "classmathematics_1_1math__ops.html", null ]
+      [ "math_ops", "classmathematics_1_1math__ops.html", "classmathematics_1_1math__ops" ]
     ] ],
     [ "nodes", "namespacenodes.html", [
       [ "doubly_linked_list", "classnodes_1_1doubly__linked__list.html", "classnodes_1_1doubly__linked__list" ],
